@@ -36,7 +36,7 @@ class LAParams:
         # In many cases, the whole word_margin mechanism is useless because space characters are
         # already included in the text. In fact, it's even harmful because it sometimes causes
         # spurious space characters to be inserted. when heuristic_word_margin is enabled, text
-        # lines already containing space characters will have their word margin multiplied by 3 to
+        # lines already containing space characters will have their word margin multiplied by 5 to
         # avoid this spurious space problem. We don't skip space insertion altogether because it's
         # possible that a layout peculiarity causes a big space not to contain the space character
         # itself, and we want to count those.
@@ -293,8 +293,9 @@ class LTTextLine(LTTextContainer):
         LTTextContainer.analyze(self, laparams)
         word_margin = laparams.word_margin
         if laparams.heuristic_word_margin and any(obj.get_text() == ' ' for obj in self._objs):
-            word_margin *= 3
-        self._insert_anon_spaces(word_margin)
+            word_margin *= 5
+        if word_margin:
+            self._insert_anon_spaces(word_margin)
         LTContainer.add(self, LTAnon('\n'))
 
     def find_neighbors(self, plane, ratio):
@@ -304,14 +305,9 @@ class LTTextLineHorizontal(LTTextLine):
 
     def __init__(self):
         LTTextLine.__init__(self)
-        self._last_char = None
-        # for height average
-        self._charheight_sum = 0
-        self._charcount = 0
+        self._chars_by_height = None
 
     def _insert_anon_spaces(self, word_margin):
-        if not word_margin:
-            return
         insertpos = []
         for i, (prev, obj) in enumerate(trailiter(self._objs, skipfirst=True)):
             if prev.get_text() == ' ' or obj.get_text() == ' ':
@@ -326,21 +322,26 @@ class LTTextLineHorizontal(LTTextLine):
     
     def add(self, obj):
         LTTextLine.add(self, obj)
-        self._charheight_sum += obj.height
-        self._charcount += 1
+        self._chars_by_height = None
     
     def find_neighbors(self, plane, ratio):
         h = ratio*self.height
         objs = plane.find((self.x0, self.y0-h, self.x1, self.y1+h))
-        ACCEPTABLE_DIFF = 3
+        # We use line_margin (ratio) as the threshold for line-height diff, which is somewhat
+        # wrong, but in effect, the two number pretty much always go together. Well, future will
+        # tell.
+        max_height_diff = ratio
         acceptable = lambda obj: isinstance(obj, LTTextLineHorizontal) and\
-            abs(obj.avg_charheight - self.avg_charheight) < ACCEPTABLE_DIFF
+            abs(obj.median_charheight - self.median_charheight) < max_height_diff
         return [obj for obj in objs if acceptable(obj)]
     
     @property
-    def avg_charheight(self):
-        if self._charcount:
-            return self._charheight_sum / self._charcount
+    def median_charheight(self):
+        if not self._chars_by_height:
+            chars = [o for o in self._objs if isinstance(o, LTChar)]
+            self._chars_by_height = sorted(chars, key=lambda c: c.height)
+        if self._chars_by_height:
+            return self._chars_by_height[len(self._chars_by_height) // 2].height
         else:
             return 0
     
@@ -348,8 +349,6 @@ class LTTextLineHorizontal(LTTextLine):
 class LTTextLineVertical(LTTextLine):
 
     def _insert_anon_spaces(self, word_margin):
-        if not word_margin:
-            return
         insertpos = []
         for i, (prev, obj) in enumerate(trailiter(self._objs, skipfirst=True)):
             margin = word_margin * obj.height
